@@ -76,6 +76,15 @@ initcanvas (void)
 
     m = Py_InitModule ("gnome.canvas", pycanvas_functions);
     d = PyModule_GetDict (m);
+
+      /* ArtPathcode */
+#define add_item(short)\
+    PyModule_AddIntConstant (m, #short, ART_##short)
+    add_item(MOVETO);
+    add_item(MOVETO_OPEN);
+    add_item(CURVETO);
+    add_item(LINETO);
+#undef add_item
 	
     pycanvas_register_classes (d);
     /* pycanvas_add_constants (d, "GNOME_CANVAS_"); */
